
local MakePlayerCharacter = require "prefabs/player_common"


local assets = {

        Asset( "ANIM", "anim/player_basic.zip" ),
        Asset( "ANIM", "anim/player_idles_shiver.zip" ),
        Asset( "ANIM", "anim/player_actions.zip" ),
        Asset( "ANIM", "anim/player_actions_axe.zip" ),
        Asset( "ANIM", "anim/player_actions_pickaxe.zip" ),
        Asset( "ANIM", "anim/player_actions_shovel.zip" ),
        Asset( "ANIM", "anim/player_actions_blowdart.zip" ),
        Asset( "ANIM", "anim/player_actions_eat.zip" ),
        Asset( "ANIM", "anim/player_actions_item.zip" ),
        Asset( "ANIM", "anim/player_actions_uniqueitem.zip" ),
        Asset( "ANIM", "anim/player_actions_bugnet.zip" ),
        Asset( "ANIM", "anim/player_actions_fishing.zip" ),
        Asset( "ANIM", "anim/player_actions_boomerang.zip" ),
        Asset( "ANIM", "anim/player_bush_hat.zip" ),
        Asset( "ANIM", "anim/player_attacks.zip" ),
        Asset( "ANIM", "anim/player_idles.zip" ),
        Asset( "ANIM", "anim/player_rebirth.zip" ),
        Asset( "ANIM", "anim/player_jump.zip" ),
        Asset( "ANIM", "anim/player_amulet_resurrect.zip" ),
        Asset( "ANIM", "anim/player_teleport.zip" ),
        Asset( "ANIM", "anim/wilson_fx.zip" ),
        Asset( "ANIM", "anim/player_one_man_band.zip" ),
        Asset( "ANIM", "anim/shadow_hands.zip" ),
        Asset( "SOUND", "sound/sfx.fsb" ),
        Asset( "SOUND", "sound/wilson.fsb" ),
        Asset( "ANIM", "anim/beard.zip" ),

        Asset( "ANIM", "anim/tahu.zip" ),
        Asset( "ANIM", "anim/ghost_tahu_build.zip" ),
}
local prefabs = {
	"tahusword",
}

-- Custom starting items
local start_inv = {
	"tahusword",
}

local function RestoreLight(inst)
    inst.Light:Enable(true)
	inst.Light:SetRadius(0.5)
    inst.Light:SetFalloff(.6)
    inst.Light:SetIntensity(0.9)
    inst.Light:SetColour(255/255,0/155,0/255)
end

-- When the character is revived from human
local function onbecamehuman(inst)
	-- Set speed when loading or reviving from ghost (optional)
	inst.components.locomotor.walkspeed = TUNING.WILSON_WALK_SPEED
	inst.components.locomotor.runspeed = TUNING.WILSON_RUN_SPEED
end

-- When loading or spawning the character
local function onload(inst)
    inst:ListenForEvent("ms_respawnedfromghost", onbecamehuman)

    if not inst:HasTag("playerghost") then
        onbecamehuman(inst)
    end
end


-- This initializes for both the server and client. Tags can be added here.
local common_postinit = function(inst) 
	-- Minimap icon
	inst.MiniMapEntity:SetIcon( "tahu.tex" )
end

-- This initializes for the server only. Components are added here.
local master_postinit = function(inst)
	-- choose which sounds this character will play
	inst.soundsname = "wx78"
	
	-- Uncomment if "wathgrithr"(Wigfrid) or "webber" voice is used
    --inst.talker_path_override = "dontstarve_DLC001/characters/"
	
	-- Stats	
	inst.components.health:SetMaxHealth(150)
	inst.components.hunger:SetMax(150)
	inst.components.sanity:SetMax(200)

	inst.components.temperature.maxtemp = 30
	inst.components.temperature.hurtrate = 2
	inst.components.health.fire_damage_scale = 0
	inst.components.sanity.night_drain_mult = 1
    	inst.components.sanity.neg_aura_mult = 1

	inst.entity:AddLight()
    inst.Light:Enable(true)
    inst.Light:SetRadius(0.5)
    inst.Light:SetFalloff(.6)
    inst.Light:SetIntensity(0.9)
    inst.Light:SetColour(255/255,0/155,0/255)
	
	-- Damage multiplier (optional)
    inst.components.combat.damagemultiplier = 1
	
	-- Hunger rate (optional)
	inst.components.hunger.hungerrate = 0.5 * TUNING.WILSON_HUNGER_RATE
	inst.components.eater.ignoresspoilage = true
	inst.components.eater.strongstomach = true

	if TheWorld.state.iswinter then
		inst.components.health:SetMaxHealth(90)
		inst.components.combat.damagemultiplier = 1
		inst.components.locomotor.walkspeed = (TUNING.WILSON_WALK_SPEED)
		inst.components.locomotor.runspeed = (TUNING.WILSON_RUN_SPEED)
		inst.components.sanity.night_drain_mult = 1
    		inst.components.sanity.neg_aura_mult = 1
	end

	if TheWorld.state.issummer then
		inst.components.health:SetMaxHealth(200)
		inst.components.combat.damagemultiplier = 1.5
		inst.components.locomotor.walkspeed = (TUNING.WILSON_WALK_SPEED * 1.2)
		inst.components.locomotor.runspeed = (TUNING.WILSON_RUN_SPEED * 1.2)
		inst.components.sanity.night_drain_mult = 0
    		inst.components.sanity.neg_aura_mult = 0
	end

	inst:WatchWorldState("startwinter", function() -- Announce Winter starting, set max temp and damage rate
		if inst.components.talker then
			inst.components.health:SetMaxHealth(90)
			inst.components.combat.damagemultiplier = 1
			inst.components.locomotor.walkspeed = (TUNING.WILSON_WALK_SPEED)
			inst.components.locomotor.runspeed = (TUNING.WILSON_RUN_SPEED)
			inst.components.sanity.night_drain_mult = 1
    			inst.components.sanity.neg_aura_mult = 1
			
		end
	end)

	inst:WatchWorldState("startspring", function() -- Announce Winter ending, set max temp and damage rate
		if inst.components.talker then
			inst.components.health:SetMaxHealth(150)
			inst.components.combat.damagemultiplier = 1
			inst.components.locomotor.walkspeed = (TUNING.WILSON_WALK_SPEED)
			inst.components.locomotor.runspeed = (TUNING.WILSON_RUN_SPEED)
			inst.components.sanity.night_drain_mult = 1
    			inst.components.sanity.neg_aura_mult = 1
		end
	end)
	
	inst:WatchWorldState("startsummer", function() -- Set max temp and damage rate
		if inst.components.talker then
			inst.components.health:SetMaxHealth(200)
			inst.components.combat.damagemultiplier = 1.5
			inst.components.locomotor.walkspeed = (TUNING.WILSON_WALK_SPEED * 1.2)
			inst.components.locomotor.runspeed = (TUNING.WILSON_RUN_SPEED * 1.2)
			inst.components.sanity.night_drain_mult = 0
    			inst.components.sanity.neg_aura_mult = 0
		end
	end)
	
	inst:WatchWorldState("startautumn", function() -- Set max temp and damage rate
		if inst.components.talker then
			inst.components.health:SetMaxHealth(150)
			inst.components.combat.damagemultiplier = 1
			inst.components.locomotor.walkspeed = (TUNING.WILSON_WALK_SPEED)
			inst.components.locomotor.runspeed = (TUNING.WILSON_RUN_SPEED)
			inst.components.sanity.night_drain_mult = 1
    			inst.components.sanity.neg_aura_mult = 1
		end
	end)



	
	inst.OnLoad = onload
    inst.OnNewSpawn = onload
end

return MakePlayerCharacter("tahu", prefabs, assets, common_postinit, master_postinit, start_inv)
